Data documentation compiled by Great Expectations

### Overview

#### Dataset info

Number of variables | 69
Number of observations expect_table_row_count_to_be_between | 403
Missing cells | 0.00%

#### Variable types

int | 67
float | 0
string | 2
-- | 0

#### Expectation types

- expect_column_proportion_of_unique_values_to_be_between 69
- expect_column_unique_value_count_to_be_between 69
- expect_column_values_to_be_in_set 69
- expect_column_values_to_be_in_type_list 69
- expect_column_values_to_not_be_null 69
- expect_column_distinct_values_to_be_in_set 67
- expect_column_values_to_not_match_regex 2
- expect_column_values_to_be_unique 1
- expect_table_row_count_to_be_between 1
- expect_table_columns_to_match_ordered_list 1

### EPISODE expect_column_to_exist

##### Type: string expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 403
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 100.0%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

S05E01 S05E03 S15E01 S15E02 S15E03 S15E04 S15E05 S15E06 S15E07 S15E08 S15E09 S16E01 S16E02 S16E03 S16E04 S16E05 S16E06 S16E07 S16E08 S16E09

### TITLE expect_column_to_exist

##### Type: string expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 401
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 99.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

"LAKESIDE CABIN" "MOUNTAIN WATERFALL" "AT DAWN'S LIGHT" "CABIN IN THE HOLLOW" "CRIMSON OVAL" "DAYS GONE BY" "DOWNSTREAM VIEW" "ISLAND PARADISE" "LONE MOUNTAIN" "PORTRAIT OF SALLY" "REFLECTIONS OF CALM" "RUSTIC BARN" "SHADES OF GREY" "STORMY SEAS" "THE OLD WEATHERED BARN" "THE PROPERTY LINE" "TRANQUIL VALLEY" "WILDERNESS DAY" "WINTER NIGHT" "WINTER STILLNESS"

### APPLE_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### AURORA_BOREALIS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### BARN expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### BEACH expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### BOAT expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### BRIDGE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### BUILDING expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### BUSHES expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### CABIN expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### CACTUS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### CIRCLE_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### CIRRUS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### CLIFF expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### CLOUDS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### CONIFER expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

1 0

#### Value Counts expect_column_distinct_values_to_be_in_set

### CUMULUS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### DECIDUOUS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

1 0

#### Value Counts expect_column_distinct_values_to_be_in_set

### DIANE_ANDRE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### DOCK expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### DOUBLE_OVAL_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### FARM expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### FENCE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### FIRE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### FLORIDA_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### FLOWERS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### FOG expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### FRAMED expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### GRASS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### GUEST expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### HALF_CIRCLE_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### HALF_OVAL_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### HILLS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### LAKE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### LAKES expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 1
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.2%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0

#### Value Counts expect_column_distinct_values_to_be_in_set

### LIGHTHOUSE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### MILL expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### MOON expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### MOUNTAIN expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### MOUNTAINS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### NIGHT expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### OCEAN expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### OVAL_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### PALM_TREES expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### PATH expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### PERSON expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### PORTRAIT expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### RECTANGLE_3D_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### RECTANGULAR_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### RIVER expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### ROCKS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### SEASHELL_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### SNOW expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### SNOWY_MOUNTAIN expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### SPLIT_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### STEVE_ROSS expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### STRUCTURE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### SUN expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### TOMB_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### TREE expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

1 0

#### Value Counts expect_column_distinct_values_to_be_in_set

### TREES expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

1 0

#### Value Counts expect_column_distinct_values_to_be_in_set

### TRIPLE_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### WATERFALL expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### WAVES expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### WINDMILL expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### WINDOW_FRAME expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### WINTER expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

### WOOD_FRAMED expect_column_to_exist

##### Type: int expect_column_values_to_be_of_type
expect_column_values_to_be_in_type_list

#### Properties

Distinct (n) expect_column_unique_value_count_to_be_between | 2
Distinct (%) expect_column_proportion_of_unique_values_to_be_between | 0.5%
Missing (n) expect_column_values_to_not_be_null | 0
Missing (%) expect_column_values_to_not_be_null | 0.0%

#### Example Values expect_column_values_to_be_in_set

0 1

#### Value Counts expect_column_distinct_values_to_be_in_set

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.